==> com_clubmanagement_1.1.zip: site/views/members/view.html.php <==
<?php
jimport( 'joomla.application.component.view');

class ClubmanagementViewMembers extends JView
{
	function display($tpl = null)
	{
//die();
		$model	  = &$this->getModel('people');
//print_r($model);
		//$model	  = &$this->getModel('members');
#print_r($model);
//echo JRequest::getVar('layout');

		$menu  = JSite::getMenu()->getActive();
		$params = &JComponentHelper::getParams( 'com_clubmanagement' );

		switch(JRequest::getVar('layout')) {
			case "personalfactsheet":
				$people = $model->getData(JRequest::getInt('people_id'));
//var_dump($people);
				$this->assignRef('people', $people[0]);
				$params->merge( new JParameter( $people[0]->params ) );
				
				$membershipData = $model->getMembershipData();
				$this->assignRef('membershipData', $membershipData);

				$positions = $model->getSpecialPositions();
				$this->assignRef('positions', $positions);

				$contacts = $model->getContacts();
				$this->assignRef('contacts', $contacts);

				$tournaments = $model->getTournaments();
				$this->assignRef('tournaments', $tournaments);
			break;
			case "sectionlist":
				$model = &$this->getModel('sections');
				//$items = $model->getData();
				
				print_r($model);
				print_r($items);
			break;
			case "sectionmembers":
				$sid = JRequest::getInt('section_id');
				$membermodel = &$this->getModel('members');
				$sm = $membermodel->getSectionmembers($sid);
				//print_r($membermodel);
				//echo "HHHH";
				//print_r($m);
				$this->assignRef('sectionmembers', $sm);
			break;
		}
		$this->assignRef('params', $params);

		parent::display($tpl);
	}	
}
?>

==> com_clubmanagement_1.3.zip: site/views/members/view.html.php <==
<?php
jimport( 'joomla.application.component.view');

class ClubmanagementViewMembers extends JView
{
	function display($tpl = null)
	{
//die();
		$model	  = $this->getModel('people');
//print_r($model);
		//$model	  = &$this->getModel('members');
#print_r($model);
//echo get_class($model);
//echo JRequest::getVar('layout');

		$menu  = JSite::getMenu()->getActive();
		$params = JComponentHelper::getParams( 'com_clubmanagement' );

		switch(JRequest::getVar('layout')) {
			case "personalfactsheet":
//print_r($model);
				$people = $model->getData(JRequest::getInt('people_id'));
//var_dump($people);
				$this->assignRef('people', $people[0]);
				$params->merge( new JParameter( $people[0]->params ) );
				
				$membershipData = $model->getMembershipData();
				$this->assignRef('membershipData', $membershipData);

				$positions = $model->getSpecialPositions();
				$this->assignRef('positions', $positions);

				$contacts = $model->getContacts();
				$this->assignRef('contacts', $contacts);

				$tournaments = $model->getTournaments();
				$this->assignRef('tournaments', $tournaments);
			break;
			case "sectionlist":
				$model = &$this->getModel('sections');
				//$items = $model->getData();
				
				print_r($model);
				print_r($items);
			break;
			case "sectionmembers":
				$sid = JRequest::getInt('section_id');
				$membermodel = &$this->getModel('members');
				$sm = $membermodel->getSectionmembers($sid);
				//print_r($membermodel);
				//echo "HHHH";
				//print_r($m);
				$this->assignRef('sectionmembers', $sm);
			break;
		}
		$this->assignRef('params', $params);

		parent::display($tpl);
	}	
}
?>
